@@ -1,14 +1,15 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ellama" "20260119.2229"
+(define-package "ellama" "20260210.2207"
   "Tool for interacting with LLMs."
   '((emacs     "28.1")
     (llm       "0.24.0")
     (plz       "0.8")
     (transient "0.7")
-    (compat    "29.1"))
+    (compat    "29.1")
+    (yaml      "1.2.3"))
   :url "http://github.com/s-kostyaev/ellama"
-  :commit "c491bf4c5b6449751a55afa6772c8cdb0e167a41"
-  :revdesc "c491bf4c5b64"
+  :commit "e421fac701b1bd9d457fea215eb6f6c912a16f4f"
+  :revdesc "e421fac701b1"
   :keywords '("help" "local" "tools")
   :authors '(("Sergey Kostyaev" . "sskostyaev@gmail.com"))
   :maintainers '(("Sergey Kostyaev" . "sskostyaev@gmail.com")))
