@@ -5,9 +5,9 @@
 ;; Author: Sergey Kostyaev <sskostyaev@gmail.com>
 ;; URL: http://github.com/s-kostyaev/ellama
 ;; Keywords: help local tools
-;; Package-Requires: ((emacs "28.1") (llm "0.24.0") (plz "0.8") (transient "0.7") (compat "29.1"))
-;; Package-Version: 20260119.2229
-;; Package-Revision: c491bf4c5b64
+;; Package-Requires: ((emacs "28.1") (llm "0.24.0") (plz "0.8") (transient "0.7") (compat "29.1") (yaml "1.2.3"))
+;; Package-Version: 20260210.2207
+;; Package-Revision: e421fac701b1
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 ;; Created: 8th Oct 2023
 
@@ -42,6 +42,7 @@
 (require 'compat)
 (eval-when-compile (require 'rx))
 (require 'ellama-tools)
+(require 'ellama-skills)
 
 (defgroup ellama nil
   "Tool for interacting with LLMs."
@@ -1213,6 +1214,42 @@ Otherwire return current active session."
 
 (defvar ellama-global-system nil)
 
+(defun ellama-get-agents-md-path ()
+  "Search for AGENTS.md file from current directory up to project root.
+Returns the full path to AGENTS.md if found, or nil if not found."
+  (let* ((current-dir (file-name-directory (expand-file-name default-directory)))
+         (project-root (file-name-directory (expand-file-name
+					     (ellama-tools-project-root-tool))))
+         found-path)
+    ;; Walk up from current directory to project root
+    (while (and (not found-path)
+		(or (string= current-dir project-root)
+		    (string> current-dir project-root)))
+      (let ((agents-path (expand-file-name "AGENTS.md" current-dir)))
+        (when (file-exists-p agents-path)
+          (setq found-path agents-path)))
+      ;; Move to parent directory
+      (setq current-dir (file-name-directory (expand-file-name ".." current-dir))))
+    found-path))
+
+(defun ellama-get-agents-md ()
+  "Return current project or subproject AGENTS.md content."
+  (or (when-let ((path (ellama-get-agents-md-path)))
+	(concat
+	 "\n"
+	 (with-temp-buffer
+	   (insert-file-contents path)
+	   (buffer-string))))
+      ""))
+
+(defun ellama-get-system-message ()
+  "Return the effective system message, including dynamically scanned skills."
+  (let ((msg (concat (or ellama-global-system "")
+		     (ellama-get-agents-md)
+		     (ellama-skills-generate-prompt))))
+    (when (not (string= msg ""))
+      msg)))
+
 (defvar-local ellama--stop-scroll nil)
 
 ;;;###autoload
@@ -1466,6 +1503,8 @@ in.  Default value is (current-buffer).
 
 :point POINT -- POINT is the point in buffer to insert ellama reply at.
 
+:tools LIST -- LIST of enabled in the current session tools.
+
 :filter FILTER -- FILTER is a function that's applied to (partial) response
 strings before they're inserted into the BUFFER.
 
@@ -1511,7 +1550,13 @@ failure (with BUFFER current).
 	 (donecb (or (plist-get args :on-done) #'ignore))
 	 (prompt-with-ctx (ellama-context-prompt-with-context prompt))
 	 (system (or (plist-get args :system)
-		     ellama-global-system))
+		     (ellama-get-system-message)))
+	 (session-tools (and session
+                             (ellama-session-extra session)
+                             (plist-get (ellama-session-extra session) :tools)))
+	 (tools (or session-tools
+		    (plist-get args :tools)
+		    ellama-tools-enabled))
 	 (llm-prompt (if session
 			 (if (llm-chat-prompt-p (ellama-session-prompt session))
 			     (progn
@@ -1519,7 +1564,7 @@ failure (with BUFFER current).
 				(ellama-session-prompt session)
 				prompt-with-ctx)
 			       (setf (llm-chat-prompt-tools (ellama-session-prompt session))
-				     ellama-tools-enabled)
+				     tools)
 			       (when system
 				 (llm-chat-prompt-append-response
 				  (ellama-session-prompt session)
@@ -1527,9 +1572,9 @@ failure (with BUFFER current).
 			       (ellama-session-prompt session))
 			   (setf (ellama-session-prompt session)
 				 (llm-make-chat-prompt prompt-with-ctx :context system
-						       :tools ellama-tools-enabled)))
+						       :tools tools)))
 		       (llm-make-chat-prompt prompt-with-ctx :context system
-					     :tools ellama-tools-enabled))))
+					     :tools tools))))
     (with-current-buffer reasoning-buffer
       (org-mode))
     (with-current-buffer buffer
